@@ -73,7 +73,7 @@ def get_python_function_from_location(
     return my_function
 
 
-def load_all_modules_from_dir(dirname):
+def load_all_modules_from_dir(dirname: str) -> None:
     for importer, package_name, _ in pkgutil.iter_modules([dirname]):
         full_package_name = '%s.%s' % (dirname, package_name)
         if full_package_name not in sys.modules:
